@@ -14,6 +14,7 @@
 #    under the License.
 
 import collections
+import collections.abc
 import datetime
 import functools
 import io
@@ -88,24 +89,24 @@ class JSONUtilsTestMixin(object):
 
     def test_loads_unicode(self):
         self.assertIsInstance(jsonutils.loads(b'"foo"'), str)
-        self.assertIsInstance(jsonutils.loads(u'"foo"'), str)
+        self.assertIsInstance(jsonutils.loads('"foo"'), str)
 
         # 'test' in Ukrainian
-        i18n_str_unicode = u'"\u0442\u0435\u0441\u0442"'
+        i18n_str_unicode = '"\u0442\u0435\u0441\u0442"'
         self.assertIsInstance(jsonutils.loads(i18n_str_unicode), str)
 
         i18n_str = i18n_str_unicode.encode('utf-8')
         self.assertIsInstance(jsonutils.loads(i18n_str), str)
 
     def test_loads_with_kwargs(self):
-        jsontext = u'{"foo": 3}'
+        jsontext = '{"foo": 3}'
         result = jsonutils.loads(jsontext, parse_int=lambda x: 5)
         self.assertEqual(5, result['foo'])
 
     def test_load(self):
 
-        jsontext = u'{"a": "\u0442\u044d\u0441\u0442"}'
-        expected = {u'a': u'\u0442\u044d\u0441\u0442'}
+        jsontext = '{"a": "\u0442\u044d\u0441\u0442"}'
+        expected = {'a': '\u0442\u044d\u0441\u0442'}
 
         for encoding in ('utf-8', 'cp1251'):
             fp = io.BytesIO(jsontext.encode(encoding))
@@ -241,9 +242,9 @@ class ToPrimitiveTestCase(test_base.BaseTestCase):
         self.assertEqual({'iteritems': 'iteritems'}, p)
 
     def test_mapping(self):
-        # Make sure collections.Mapping is converted to a dict
+        # Make sure collections.abc.Mapping is converted to a dict
         # and not a list.
-        class MappingClass(collections.Mapping):
+        class MappingClass(collections.abc.Mapping):
             def __init__(self):
                 self.data = dict(a=1, b=2, c=3)
 
@@ -260,8 +261,7 @@ class ToPrimitiveTestCase(test_base.BaseTestCase):
         p = jsonutils.to_primitive(x)
         self.assertEqual({'a': 1, 'b': 2, 'c': 3}, p)
 
-    @mock.patch('warnings.warn')
-    def test_instance(self, warn_mock):
+    def test_instance(self):
         class MysteryClass(object):
             a = 10
 
@@ -272,8 +272,7 @@ class ToPrimitiveTestCase(test_base.BaseTestCase):
         self.assertEqual(dict(b=1),
                          jsonutils.to_primitive(x, convert_instances=True))
 
-        self.assertEqual(x, jsonutils.to_primitive(x))
-        warn_mock.assert_called_once()
+        self.assertRaises(ValueError, jsonutils.to_primitive, x)
 
     def test_typeerror(self):
         x = bytearray  # Class, not instance
@@ -324,12 +323,12 @@ class ToPrimitiveTestCase(test_base.BaseTestCase):
         self.assertEqual({'ip_addr': '1.2.3.4'}, ret)
 
     def test_ipaddr_using_ipaddress_v4(self):
-        thing = {'ip_addr': ipaddress.ip_address(u'192.168.0.1')}
+        thing = {'ip_addr': ipaddress.ip_address('192.168.0.1')}
         ret = jsonutils.to_primitive(thing)
         self.assertEqual({'ip_addr': '192.168.0.1'}, ret)
 
     def test_ipaddr_using_ipaddress_v6(self):
-        thing = {'ip_addr': ipaddress.ip_address(u'2001:db8::')}
+        thing = {'ip_addr': ipaddress.ip_address('2001:db8::')}
         ret = jsonutils.to_primitive(thing)
         self.assertEqual({'ip_addr': '2001:db8::'}, ret)
 
@@ -353,8 +352,7 @@ class ToPrimitiveTestCase(test_base.BaseTestCase):
     def test_fallback(self):
         obj = ReprObject()
 
-        ret = jsonutils.to_primitive(obj)
-        self.assertIs(obj, ret)
+        self.assertRaises(ValueError, jsonutils.to_primitive, obj)
 
         ret = jsonutils.to_primitive(obj, fallback=repr)
         self.assertEqual('repr', ret)
@@ -363,8 +361,7 @@ class ToPrimitiveTestCase(test_base.BaseTestCase):
         obj = ReprObject()
         obj_list = [obj]
 
-        ret = jsonutils.to_primitive(obj_list)
-        self.assertEqual([obj], ret)
+        self.assertRaises(ValueError, jsonutils.to_primitive, obj_list)
 
         ret = jsonutils.to_primitive(obj_list, fallback=repr)
         self.assertEqual(['repr'], ret)
